<h1 align="center">
<img src="docs/holistic_ai.png" width="100">
<br>Holistic AI
</h1>

The Holistic AI library is an open-source tool to assess and improve the trustworthiness of AI systems.  

Currently, the library offers a set of techniques to easily measure and mitigate Bias across numerous tasks. In the future, it will be extended to include tools for Efficacy, Robustness, Privacy and Explainability as well. This will allow a holistic assessment of AI systems.  

- Documentation:https://holisticai.readthedocs.io/en/latest/ 
- Tutorials: https://github.com/holistic-ai/holisticai/tree/main/tutorials
- Source code: https://github.com/holistic-ai/holisticai/tree/main
- Holistic Ai website: https://holisticai.com

## Installation

Install the library with:

    pip install holisticai
